summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_html_live_status.py
diff options
context:
space:
mode:
Diffstat (limited to 'bin/reproducible_html_live_status.py')
-rwxr-xr-xbin/reproducible_html_live_status.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_html_live_status.py b/bin/reproducible_html_live_status.py
index efb3c13f..e3faa5b9 100755
--- a/bin/reproducible_html_live_status.py
+++ b/bin/reproducible_html_live_status.py
@@ -74,8 +74,8 @@ def generate_live_status_table(arch):
counter = 0
for row in rows:
counter += 1
- # the numbers 16 and 7 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
- if ( arch == 'amd64' and counter == 16 ) or ( arch == 'armhf' and counter == 7 ):
+ # the numbers 13 and 7 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
+ if ( arch == 'amd64' and counter == 13 ) or ( arch == 'armhf' and counter == 7 ):
html += '<tr><td colspan="10">There are more builds marked as currently building in the database than there are ' + arch + ' build jobs. This does not compute. Please cleanup and please automate cleanup.</td></tr>'
suite = row[1]
arch = row[2]